@@ -235,10 +235,11 @@ main (int argc, char **argv)
 	GtkWidget *pixmap = NULL;
 	gchar *msg, *s;
 
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
- 	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+ 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_init ("gnome-login-check", VERSION, argc, argv);
+	gnome_init ("gnome-login-check", "0.1", argc, argv);
 
 	gdk_window_get_pointer (GDK_ROOT_PARENT(), NULL, NULL, &state);
 
