@@ -67,15 +67,31 @@ iris_callback (gpointer data)
   height_step = MIN (iris_rect.width / 2, iris_block);
 
   for (i = 0; i < MIN (width_step, height_step); i++)
-    gdk_draw_rectangle (GDK_ROOT_PARENT (), iris_gc, FALSE,
-			iris_rect.x + i, iris_rect.y + i,
-			(gint)iris_rect.width - 2 * i,
-			(gint)iris_rect.height - 2 * i);
+    {
+      GdkPoint points[5];
+      static gchar dash_list[2] =
+      {1, 1};
+
+      gdk_gc_set_dashes (iris_gc, i % 1, dash_list, 2);
+
+      points[0].x = iris_rect.x + i;
+      points[0].y = iris_rect.y + i;
+      points[1].x = iris_rect.x + iris_rect.width - i;
+      points[1].y = iris_rect.y + i;
+      points[2].x = iris_rect.x + iris_rect.width - i;
+      points[2].y = iris_rect.y + iris_rect.height - i;
+      points[3].x = iris_rect.x + i;
+      points[3].y = iris_rect.y + iris_rect.height - i;
+      points[4].x = iris_rect.x + i;
+      points[4].y = iris_rect.y + i;
+
+      gdk_draw_lines (GDK_ROOT_PARENT (), iris_gc, points, 5);
+    }
 
   gdk_flush ();
 
   iris_rect.x += width_step;
-  iris_rect.y += height_step;
+  iris_rect.y += width_step;
   iris_rect.width -= MIN (iris_rect.width, iris_block * 2);
   iris_rect.height -= MIN (iris_rect.height, iris_block * 2);
 
@@ -99,7 +115,6 @@ iris (void)
   if (!iris_gc)
     {
       GdkGCValues values;
-      static gchar dash_list[2] = {1, 1};
 
       values.line_style = GDK_LINE_ON_OFF_DASH;
       values.subwindow_mode = GDK_INCLUDE_INFERIORS;
@@ -107,8 +122,6 @@ iris (void)
       iris_gc = gdk_gc_new_with_values (GDK_ROOT_PARENT (),
 					&values,
 				      GDK_GC_LINE_STYLE | GDK_GC_SUBWINDOW);
-
-      gdk_gc_set_dashes (iris_gc, 0, dash_list, 2);
     }
 
   /* Plan for a time of 0.5 seconds for effect */
@@ -289,12 +302,15 @@ display_gui (void)
     case 1:
       return FALSE;
     case 2:
+/* FIXME: port to gnome 2 help stuff */
+#if 0
       {
 	GnomeHelpMenuEntry help_entry = {
 	  "panel", "panelbasics.html#LOGGINGOUT"
 	};
 	gnome_help_display (NULL, &help_entry);
       }
+#endif
       return FALSE;
     }
 }
