@@ -19,6 +19,38 @@ struct _PanelAppletShellPrivate {
 
 static GObjectClass *parent_class = NULL;
 
+static void
+impl_PanelAppletShell_saveYourself (PortableServer_Servant  servant,
+				    const CORBA_char       *global_key,
+				    const CORBA_char       *private_key,
+				    CORBA_Environment      *ev)
+{
+	PanelAppletShell *shell;
+
+	shell = PANEL_APPLET_SHELL (bonobo_object (servant));
+
+	panel_applet_save_yourself (shell->priv->applet, global_key, private_key);
+}
+
+static void
+impl_PanelAppletShell_getExpandFlags (PortableServer_Servant  servant,
+				      const CORBA_boolean    *expand_major,
+				      const CORBA_boolean    *expand_minor,
+				      CORBA_Environment      *ev)
+{
+	PanelAppletShell *shell;
+	gboolean major, minor;
+
+	shell = PANEL_APPLET_SHELL (bonobo_object (servant));
+
+	panel_applet_get_expand_flags (shell->priv->applet,
+				       &major, &minor);
+
+	*expand_major = major;
+	*expand_minor = minor;
+}
+
+
 static void
 panel_applet_shell_finalize (GObject *object)
 {
@@ -37,7 +69,8 @@ panel_applet_shell_class_init (PanelAppletShellClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	klass->epv.dummy = NULL;
+	klass->epv.saveYourself = impl_PanelAppletShell_saveYourself;
+	klass->epv.getExpandFlags = impl_PanelAppletShell_getExpandFlags;
 
 	object_class->finalize = panel_applet_shell_finalize;
 
