@@ -6,16 +6,15 @@
  */
 
 #include "config.h"
+#include "panel-marshal.h"
 #include "aligned-widget.h"
 #include "panel_config_global.h"
 #include "foobar-widget.h"
 #include "multiscreen-stuff.h"
-
-extern GlobalConfig global_config;
-extern int pw_minimized_size;
+#include "panel-typebuiltins.h"
 
 static void aligned_pos_class_init (AlignedPosClass *klass);
-static void aligned_pos_init (AlignedPos *pos);
+static void aligned_pos_instance_init (AlignedPos *pos);
 
 static void aligned_pos_set_pos (BasePWidget *basep,
 				 int x, int y,
@@ -27,30 +26,31 @@ static void aligned_pos_get_pos (BasePWidget *basep,
 
 static void aligned_pos_show_hide_left (BasePWidget *basep);
 static void aligned_pos_show_hide_right (BasePWidget *basep);
-static BorderPosClass *parent_class;
+static BorderPosClass *aligned_pos_parent_class;
 
-GtkType
+GType
 aligned_pos_get_type (void)
 {
-	static GtkType aligned_pos_type = 0;
+	static GType object_type = 0;
 
-	if (aligned_pos_type == 0) {
-		GtkTypeInfo aligned_pos_info = {
-			"AlignedPos",
-			sizeof (AlignedPos),
-			sizeof (AlignedPosClass),
-			(GtkClassInitFunc) aligned_pos_class_init,
-			(GtkObjectInitFunc) aligned_pos_init,
-			NULL,
-			NULL,
-			NULL
+	if (object_type == 0) {
+		static const GTypeInfo object_info = {
+                    sizeof (AlignedPosClass),
+                    (GBaseInitFunc)         NULL,
+                    (GBaseFinalizeFunc)     NULL,
+                    (GClassInitFunc)        aligned_pos_class_init,
+                    NULL,                   /* class_finalize */
+                    NULL,                   /* class_data */
+                    sizeof (AlignedPos),
+                    0,                      /* n_preallocs */
+                    (GInstanceInitFunc)     aligned_pos_instance_init
 		};
 
-		aligned_pos_type = gtk_type_unique (TYPE_BORDER_POS,
-						    &aligned_pos_info);
+		object_type = g_type_register_static (BORDER_TYPE_POS, "AlignedPos", &object_info, 0);
+		aligned_pos_parent_class = g_type_class_ref (BORDER_TYPE_POS);
 	}
 			       
-	return aligned_pos_type;
+	return object_type;
 }
 
 enum {
@@ -63,23 +63,21 @@ static guint aligned_pos_signals[LAST_SIGNAL] = { 0 };
 static void
 aligned_pos_class_init (AlignedPosClass *klass)
 {
-	BasePPosClass *pos_class = BASEP_POS_CLASS(klass);
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-	parent_class = gtk_type_class(TYPE_BORDER_POS);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	BasePPosClass *pos_class = BASEP_POS_CLASS (klass);
+
 	
 	aligned_pos_signals[ALIGN_CHANGE_SIGNAL] =
-		gtk_signal_new ("align_change",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (AlignedPosClass,
-						   align_change),
-				gtk_marshal_NONE__ENUM,
-				GTK_TYPE_NONE,
-				1, GTK_TYPE_ENUM);
-
-	gtk_object_class_add_signals (object_class,
-				      aligned_pos_signals,
-				      LAST_SIGNAL);
+		g_signal_new ("align_change",
+			      G_SIGNAL_RUN_LAST,
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_STRUCT_OFFSET (AlignedPosClass, align_change),
+			      NULL,
+			      NULL,
+			      panel_marshal_VOID__ENUM,
+			      G_TYPE_NONE,
+			      1, 
+			      PANEL_TYPE_ALIGNED_ALIGNMENT);
 
 	pos_class->set_pos = aligned_pos_set_pos;
 	pos_class->get_pos = aligned_pos_get_pos;
@@ -90,7 +88,9 @@ aligned_pos_class_init (AlignedPosClass *klass)
 }
 
 static void
-aligned_pos_init (AlignedPos *pos) { }
+aligned_pos_instance_init (AlignedPos *pos) {
+	/* Does nothing */
+}
 
 static void
 aligned_pos_set_pos (BasePWidget *basep,
@@ -290,8 +290,6 @@ aligned_widget_change_params (AlignedWidget *aligned,
 			      int sz,
 			      BasePMode mode,
 			      BasePState state,
-			      BasePLevel level,
-			      gboolean avoid_on_maximize,
 			      gboolean hidebuttons_enabled,
 			      gboolean hidebutton_pixmaps_enabled,
 			      PanelBackType back_type,
@@ -305,9 +303,9 @@ aligned_widget_change_params (AlignedWidget *aligned,
 
 	if (pos->align != align) {
 		pos->align = align;
-		gtk_signal_emit (GTK_OBJECT (pos),
-				 aligned_pos_signals[ALIGN_CHANGE_SIGNAL],
-				 align);
+		g_signal_emit (G_OBJECT (pos),
+			       aligned_pos_signals[ALIGN_CHANGE_SIGNAL],
+			       0, align);
 	}
 
 	border_widget_change_params (BORDER_WIDGET (aligned),
@@ -316,8 +314,6 @@ aligned_widget_change_params (AlignedWidget *aligned,
 				     sz,
 				     mode,
 				     state,
-				     level,
-				     avoid_on_maximize,
 				     hidebuttons_enabled,
 				     hidebutton_pixmaps_enabled,
 				     back_type,
@@ -346,8 +342,6 @@ aligned_widget_change_align (AlignedWidget *aligned,
 				      BORDER_POS (pos)->edge,
 				      panel->sz, basep->mode,
 				      basep->state,
-				      basep->level,
-				      basep->avoid_on_maximize,
 				      basep->hidebuttons_enabled,
 				      basep->hidebutton_pixmaps_enabled,
 				      panel->back_type,
@@ -373,8 +367,6 @@ aligned_widget_change_align_edge (AlignedWidget *aligned,
 				      panel->sz,
 				      basep->mode,
 				      basep->state,
-				      basep->level,
-				      basep->avoid_on_maximize,
 				      basep->hidebuttons_enabled,
 				      basep->hidebutton_pixmaps_enabled,
 				      panel->back_type,
@@ -391,8 +383,6 @@ aligned_widget_new (int screen,
 		    BorderEdge edge,
 		    BasePMode mode,
 		    BasePState state,
-		    BasePLevel level,
-		    gboolean avoid_on_maximize,
 		    int sz,
 		    gboolean hidebuttons_enabled,
 		    gboolean hidebutton_pixmaps_enabled,
@@ -403,8 +393,8 @@ aligned_widget_new (int screen,
 		    gboolean rotate_pixmap_bg,
 		    GdkColor *back_color)
 {
-	AlignedWidget *aligned = gtk_type_new (TYPE_ALIGNED_WIDGET);
-	AlignedPos *pos = gtk_type_new (TYPE_ALIGNED_POS);
+	AlignedWidget *aligned = gtk_type_new (ALIGNED_TYPE_WIDGET);
+	AlignedPos *pos = gtk_type_new (ALIGNED_TYPE_POS);
 	pos->align = align;
 
 	BASEP_WIDGET (aligned)->pos = BASEP_POS (pos);
@@ -417,8 +407,6 @@ aligned_widget_new (int screen,
 				 sz,
 				 mode,
 				 state,
-				 level,
-				 avoid_on_maximize,
 				 hidebuttons_enabled,
 				 hidebutton_pixmaps_enabled,
 				 back_type,
