@@ -1,9 +1,7 @@
 #ifndef CONDITIONAL_H
 #define CONDITIONAL_H
 
-BEGIN_GNOME_DECLS
-
-gboolean	conditional_parse	(const char *conditional, int len);
+G_BEGIN_DECLS
 
 /* get key, if key doesn't exist append "Conditional" to key and treat
  * value as "{<conditional1>}<value1>{<conditional2>}<value2>...",
@@ -21,6 +19,6 @@ int		conditional_get_int	(const char *key,
 /* get key and treat it as a conditional, if missing, it's true */
 gboolean	conditional_true	(const char *key);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
