@@ -8,16 +8,15 @@
 #ifndef FOOBAR_WIDGET_H
 #define FOOBAR_WIDGET_H
 
-#include <gnome.h>
 #include "panel-types.h"
 #include "gwmh.h"
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
-#define TYPE_FOOBAR_WIDGET     (foobar_widget_get_type ())
-#define FOOBAR_WIDGET(o)       (GTK_CHECK_CAST ((o), TYPE_FOOBAR_WIDGET, FoobarWidget))
-#define FOOBAR_WIDGET_CLASS(k) (GTK_CHECK_CLASS_CAST ((k), TYPE_FOOBAR_WIDGET, FoobarWidgetType))
-#define IS_FOOBAR_WIDGET(o)    (GTK_CHECK_TYPE ((o), TYPE_FOOBAR_WIDGET))
+#define FOOBAR_TYPE_WIDGET     		(foobar_widget_get_type ())
+#define FOOBAR_WIDGET(object)       	(G_TYPE_CHECK_INSTANCE_CAST ((object), FOOBAR_TYPE_WIDGET, FoobarWidget))
+#define FOOBAR_WIDGET_CLASS(klass) 	(G_TYPE_CHECK_CLASS_CAST ((klass), FOOBAR_TYPE_WIDGET, FoobarWidgetType))
+#define FOOBAR_IS_WIDGET(object)    	(G_TYPE_CHECK_INSTANCE_TYPE ((object), FOOBAR_TYPE_WIDGET))
 
 typedef struct _FoobarWidget           FoobarWidget;
 typedef struct _FoobarWidgetClass      FoobarWidgetClass;
@@ -44,7 +43,7 @@ struct _FoobarWidget
 	GHashTable *tasks;
 	GtkWidget *task_item;
 	GtkWidget *task_menu;
-	GtkWidget *task_pixmap;
+	GtkWidget *task_image;
 	GtkWidget *task_bin;
 	GwmhTask *icon_task; /* the task whoose icon is shown,
 			      * hopefully should be always OK,
@@ -62,7 +61,8 @@ struct _FoobarWidgetClass
 	GtkWindowClass panel_class;
 };
 
-GtkType		foobar_widget_get_type		(void) G_GNUC_CONST;
+GType		foobar_widget_get_type		(void) G_GNUC_CONST;
+
 GtkWidget *	foobar_widget_new		(int screen);
 
 void		foobar_widget_update_winhints	(FoobarWidget *foo);
@@ -79,6 +79,6 @@ void		foobar_widget_force_menu_remake	(void);
 
 void		foobar_widget_global_set_clock_format (const char *format);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
