@@ -7,16 +7,19 @@
  */
 
 #include <config.h>
-#include <gnome.h>
 
-#include "panel-include.h"
+#include "menu-util.h"
+
+#include "basep-widget.h"
+#include "foobar-widget.h"
 #include "multiscreen-stuff.h"
+#include "distribution.h"
+#include "panel_config_global.h"
+#include "menu.h"
 
-/*#define PANEL_DEBUG 1*/
+#undef MENU_UTIL_DEBUG
 
 extern char *kde_menudir;
-extern char *kde_icondir;
-extern char *kde_mini_icondir;
 
 extern GlobalConfig global_config;
 
@@ -28,7 +31,7 @@ add_menu_separator (GtkWidget *menu)
 	menuitem = gtk_menu_item_new ();
 	gtk_widget_set_sensitive (menuitem, FALSE);
 	gtk_widget_show (menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
 	return menuitem;
 }
@@ -79,28 +82,38 @@ panel_standard_menu_pos (GtkMenu *menu, gint *x, gint *y, gpointer data)
 }
 
 void
-panel_menu_position (GtkMenu *menu, gint *x, gint *y, gpointer data)
+panel_menu_position (GtkMenu  *menu,
+		     gint     *x,
+		     gint     *y,
+		     gboolean *push_in,
+		     gpointer  data)
 {
 	GtkWidget *w = data;
 	gint wx, wy;
 
 	g_return_if_fail (w != NULL);
 
+/* FIXME - new gtk menus ?? 
 	if ( ! global_config.off_panel_popups) {
 		panel_standard_menu_pos (menu, x, y, data);
 		return;
+	}  */
+	
+	if (TRUE) {
+		panel_standard_menu_pos (menu, x, y, data);
+		return;
 	}
 
 	gdk_window_get_origin (w->window, &wx, &wy);
 
 	gtk_widget_get_pointer(w, x, y);
-	if (IS_BASEP_WIDGET (w)) {
+	if (BASEP_IS_WIDGET (w)) {
 		basep_widget_get_menu_pos(BASEP_WIDGET(w), 
 					  GTK_WIDGET(menu),
 					  x,y,wx,wy,
 					  w->allocation.width,
 					  w->allocation.height);
-	} else if (IS_FOOBAR_WIDGET (w)) {
+	} else if (FOOBAR_IS_WIDGET (w)) {
 		GtkRequisition req;
 		FoobarWidget *foo = FOOBAR_WIDGET (w);
 		gtk_widget_get_child_requisition (GTK_WIDGET (menu), &req);
@@ -109,10 +122,16 @@ panel_menu_position (GtkMenu *menu, gint *x, gint *y, gpointer data)
 			  multiscreen_x (foo->screen) -  req.width);
 		*y = w->allocation.height + multiscreen_y (foo->screen);
 	}
+
+	*push_in = TRUE;
 }
 
 void
-applet_menu_position (GtkMenu *menu, gint *x, gint *y, gpointer data)
+applet_menu_position (GtkMenu  *menu,
+		      gint     *x,
+		      gint     *y,
+		      gboolean *push_in,
+		      gpointer  data)
 {
 	AppletInfo *info = data;
 	int wx, wy;
@@ -132,14 +151,19 @@ applet_menu_position (GtkMenu *menu, gint *x, gint *y, gpointer data)
 		wx += info->widget->allocation.x;
 		wy += info->widget->allocation.y;
 	}
-	if (IS_BASEP_WIDGET (w)) {
+
+#ifdef MENU_UTIL_DEBUG
+	g_print ("applet_menu_position: origin x = %d, y = %d\n", wx, wy);
+#endif
+
+	if (BASEP_IS_WIDGET (w)) {
 		*x = *y = 0;
 		basep_widget_get_menu_pos(BASEP_WIDGET(w),
 					  GTK_WIDGET(menu),
 					  x,y,wx,wy,
 					  info->widget->allocation.width,
 					  info->widget->allocation.height);
-       	} else if (IS_FOOBAR_WIDGET (w)) {
+       	} else if (FOOBAR_IS_WIDGET (w)) {
 		GtkRequisition req;
 		FoobarWidget *foo = FOOBAR_WIDGET (w);
 		gtk_widget_get_child_requisition (GTK_WIDGET (menu), &req);
@@ -148,11 +172,15 @@ applet_menu_position (GtkMenu *menu, gint *x, gint *y, gpointer data)
 			  multiscreen_x (foo->screen) -  req.width);
 		*y = w->allocation.height + multiscreen_y (foo->screen);
 	}
+
+	*push_in = TRUE;
+
+#ifdef MENU_UTIL_DEBUG
+	g_print ("applet_menu_position: x = %d, y = %d, push_in = %s\n",
+		 *x, *y, *push_in ? "(true)" : "(false)");
+#endif
 }
 
-/* This function is marked as const as get_distribution_type is const and
- * it would never change while the program is running.  If you change this
- * do remember to take out the G_GNUC_CONST in menu-util.h */
 int
 get_default_menu_flags (void)
 {
@@ -163,11 +191,11 @@ get_default_menu_flags (void)
 		MAIN_MENU_DESKTOP;
 	
 	/*guess distribution menus*/
-	if(distribution != DISTRIBUTION_UNKNOWN)
+	if (distribution != DISTRIBUTION_UNKNOWN)
 		flags |= MAIN_MENU_DISTRIBUTION_SUB;
 
 	/*guess KDE menus*/
-	if (panel_file_exists (kde_menudir))
+	if (g_file_test (kde_menudir, G_FILE_TEST_IS_DIR))
 		flags |= MAIN_MENU_KDE_SUB;
 
 	return flags;
