@@ -2,10 +2,11 @@
 #define PANEL_H
 
 #include <gtk/gtk.h>
+#include "basep-widget.h"
 #include "panel-widget.h"
 #include "applet.h"
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 typedef struct _PanelData PanelData;
 struct _PanelData {
@@ -15,14 +16,11 @@ struct _PanelData {
 	int menu_age;
 };
 
-void freeze_changes (AppletInfo *info);
-void thaw_changes (AppletInfo *info);
-
 void orientation_change(AppletInfo *info, PanelWidget *panel);
 void size_change(AppletInfo *info, PanelWidget *panel);
 void back_change(AppletInfo *info, PanelWidget *panel);
 
-PanelOrientType get_applet_orient(PanelWidget *panel);
+PanelOrient get_applet_orient(PanelWidget *panel);
 
 void panel_setup(GtkWidget *panel);
 void basep_pos_connect_signals (BasePWidget *basep);
@@ -30,10 +28,6 @@ void basep_pos_connect_signals (BasePWidget *basep);
 /*send state change to all the panels*/
 void send_state_change(void);
 
-void panel_freeze_changes(PanelWidget *panel);
-
-void panel_thaw_changes(PanelWidget *panel);
-
 GtkWidget * make_popup_panel_menu (PanelWidget *panel);
 
 PanelData * panel_data_by_id (int id);
@@ -47,6 +41,6 @@ void status_unparent (GtkWidget *widget);
 	 (PANEL_WIDGET(GTK_WIDGET(appletw)->parent)->panel_parent)
 
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
