@@ -29,7 +29,6 @@
 #include "distribution.h"
 #include "drawer-widget.h"
 #include "edge-widget.h"
-#include "extern.h"
 #include "floating-widget.h"
 #include "foobar-widget.h"
 #include "launcher.h"
@@ -49,6 +48,8 @@
 #include "xstuff.h"
 #include "multiscreen-stuff.h"
 #include "conditional.h"
+#include "panel-applet-frame.h"
+#include "panel-shell.h"
 
 #undef SESSION_DEBUG
 
@@ -85,21 +86,6 @@ GtkWidget *ss_timeout_dlg = NULL;
 static gboolean ss_interactive = FALSE;
 static int ss_timeout = 500;
 
-/*send the tooltips state to all external applets*/
-static void
-send_tooltips_state(gboolean enabled)
-{
-	GSList *li;
-
-	for(li = applets; li != NULL; li = li->next) {
-		AppletInfo *info = li->data;
-
-		if (info->type == APPLET_EXTERN)
-			extern_handle_set_tooltips_state ((Extern)info->data,
-							  enabled);
-	}
-}
-
 void
 apply_global_config (void)
 {
@@ -111,14 +97,14 @@ apply_global_config (void)
 	static int old_avoid_collisions = -1;
 	GSList *li;
 
-/* FIXME
+#ifdef FIXME
 	panel_widget_change_global (global_config.hiding_step_size,
 				    global_config.minimized_size,
 				    global_config.minimize_delay,
 				    global_config.maximize_delay,
 				    global_config.movement_type,
 				    global_config.disable_animations);
-*/
+#endif
 	if (global_config.tooltips_enabled)
 		gtk_tooltips_enable (panel_tooltips);
 	else
@@ -165,7 +151,6 @@ apply_global_config (void)
 	old_use_large_icons = global_config.use_large_icons;
 	old_merge_menus = global_config.merge_menus;
 	old_menu_check = global_config.menu_check;
-	send_tooltips_state(global_config.tooltips_enabled);
 
 	/* if we changed global menu flags, cmark all main menus that use
 	 * the global setting as dirty */
@@ -195,7 +180,6 @@ apply_global_config (void)
 			else if (FOOBAR_IS_WIDGET (pd->panel))
 				foobar_widget_update_winhints (FOOBAR_WIDGET (pd->panel));
 		}
-		panel_reset_dialog_layers ();
 	}
 	layer_old = global_config.layer;
 	
@@ -225,6 +209,7 @@ apply_global_config (void)
 	panel_global_keys_setup();
 }
 
+#ifdef FIXME /* Keep this code until a new one is done for applets */
 static void
 timeout_dlg_realized (GtkWidget *dialog)
 {
@@ -282,61 +267,8 @@ session_save_timeout (gpointer data)
 	gtk_widget_destroy (ss_timeout_dlg);
 	return TRUE;
 }
-
-static void
-send_applet_session_save (AppletInfo *info,
-			  CORBA_Object obj,
-			  const char *cfgpath,
-			  const char *globcfgpath)
-{
-	guint timeout;
-	CORBA_Environment ev;
-	
-	/*new unique cookie*/
-	ss_cookie++;
-	
-#ifdef SESSION_DEBUG	
-	printf("SENDING_SESSION_SAVE (%u)\n", ss_cookie);
 #endif
 
-	timeout = gtk_timeout_add(ss_timeout, session_save_timeout,
-				  GINT_TO_POINTER((int)ss_cookie));
-
-	CORBA_exception_init(&ev);
-	GNOME_Applet_save_session(obj,
-				  (CORBA_char *)cfgpath,
-				  (CORBA_char *)globcfgpath,
-				  ss_cookie, &ev);
-	if(ev._major == CORBA_SYSTEM_EXCEPTION) {
-		CORBA_SystemException *exc =
-			CORBA_exception_value(&ev);
-		if(exc &&
-		   (!strcmp (ev._id, ex_CORBA_BAD_OPERATION) ||
-		    !strcmp (ev._id, ex_CORBA_NO_IMPLEMENT))) {
-			gboolean ret;
-			gtk_timeout_remove(timeout);
-			CORBA_exception_free(&ev);
-			CORBA_exception_init(&ev);
-			ret = GNOME_Applet_session_save(obj,
-						(CORBA_char *)cfgpath,
-						(CORBA_char *)globcfgpath,
-						&ev);
-			extern_save_applet (info, ret);
-		}
-	} else if(ev._major) {
-		gtk_timeout_remove(timeout);
-		panel_applet_clean(info);
-		CORBA_exception_free(&ev);
-		save_next_applet();
-		return;
-	}
-
-	CORBA_exception_free(&ev);
-}
-
-
-
-
 /*returns TRUE if the save was completed, FALSE if we need to wait
   for the applet to respond*/
 static gboolean
@@ -362,13 +294,10 @@ save_applet_configuration(AppletInfo *info)
 			 info->applet_id+1);
 	gnome_config_push_prefix(buf->str);
 
-	/*obviously no need for saving*/
-	if (info->type == APPLET_EXTERN_PENDING ||
-	    info->type == APPLET_EXTERN_RESERVED ||
-	    info->type == APPLET_EMPTY) {
-		gnome_config_set_string("id", EMPTY_ID);
-		gnome_config_pop_prefix();
-		g_string_free(buf,TRUE);
+	if (info->type == APPLET_EMPTY) {
+		gnome_config_set_string ("id", EMPTY_ID);
+		gnome_config_pop_prefix ();
+		g_string_free (buf,TRUE);
 		return TRUE;
 	}
 
@@ -385,53 +314,9 @@ save_applet_configuration(AppletInfo *info)
 	panel_id = panel->unique_id;
 
 	switch(info->type) {
-	case APPLET_EXTERN:
-		{
-			Extern       ext = info->data;
-			GNOME_Applet applet;
-			char *s;
-
-			g_assert (info->data);
-
-			ext    = info->data;
-			applet = extern_get_applet (ext);
-
-			/*just in case the applet times out*/
-			gnome_config_set_string("id", EMPTY_ID);
-			gnome_config_pop_prefix();
-
-			/*this is the file path we must kill first */
-			g_string_sprintf(buf, "%sApplet_%d_Extern",
-					 PANEL_CONFIG_PATH, info->applet_id+1);
-			
-			/* this should really be: */
-			/*gnome_config_push_prefix("");
-			gnome_config_clean_file(buf->str);
-			gnome_config_pop_prefix();
-			gnome_config_sync();*/
-			/* but gnome-config.[ch] is broken ! */
-			s = gnome_config_get_real_path (buf->str);
-			unlink(s);
-			g_free(s);
-
-			gnome_config_sync();
-
-			/*this is the file path we pass to the applet for it's
-			  own config, this is a separate file, so that we */
-			g_string_sprintf(buf, "%sApplet_%d_Extern/",
-					 PANEL_CONFIG_PATH, info->applet_id+1);
-			/*have the applet do it's own session saving*/
-			send_applet_session_save (info,
-						  applet,
-						  buf->str,
-						  PANEL_CONFIG_PATH
-						  "Applet_All_Extern/");
-
-			/* update the configuration string */
-			extern_set_config_string (ext, buf->str);
-
-			return FALSE; /*here we'll wait for done_session_save*/
-		}
+	case APPLET_BONOBO:
+		panel_applet_frame_save_session (PANEL_APPLET_FRAME (info->data));
+		break;
 	case APPLET_DRAWER: 
 		{
 			int i;
@@ -563,9 +448,6 @@ save_panel_configuration(gpointer data, gpointer user_data)
 		gnome_config_set_int ("mode", basep->mode);
 		gnome_config_set_int ("state", basep->state);
 
-		gnome_config_set_int ("level", basep->level);
-		gnome_config_set_bool ("avoid_on_maximize",
-				       basep->avoid_on_maximize);
 		gnome_config_set_int ("screen",
 				      basep->screen);
 	}
@@ -859,7 +741,7 @@ int
 panel_session_die (GnomeClient *client,
 		   gpointer client_data)
 {
-	GSList *li;
+	GSList *l;
 
 	gtk_timeout_remove (config_sync_timeout);
 	config_sync_timeout = 0;
@@ -867,22 +749,30 @@ panel_session_die (GnomeClient *client,
 	status_inhibit = TRUE;
 	status_spot_remove_all ();
 
-	for (li = applets; li != NULL; li = li->next) {
-		AppletInfo *info = li->data;
+	for (l = applets; l; l = l->next) {
+		AppletInfo *info = l->data;
 
-		if (info->type == APPLET_EXTERN) {
-			extern_save_last_position ((Extern)info->data, FALSE);
-
-			gtk_widget_destroy (info->widget);
-		}
-		else if (info->type == APPLET_SWALLOW) {
-			Swallow *swallow = info->data;
+		switch (info->type) {
+		case APPLET_BONOBO:
+			panel_applet_frame_save_position (
+				PANEL_APPLET_FRAME (info->data));
+			break;
+		case APPLET_SWALLOW: {
+			Swallow   *swallow = info->data;
+			GtkSocket *socket;
 
 			swallow->clean_remove = TRUE;
 
-			if(GTK_SOCKET(swallow->socket)->plug_window)
-				XKillClient(GDK_DISPLAY(),
-					    GDK_WINDOW_XWINDOW(GTK_SOCKET(swallow->socket)->plug_window));
+			socket = GTK_SOCKET (swallow->socket);
+
+			if (socket->plug_window)
+                                XKillClient (GDK_DISPLAY (),
+					     GDK_WINDOW_XWINDOW(socket->plug_window));
+
+			}
+			break;
+		default:
+			break;
 		}
 	}
 
@@ -890,9 +780,10 @@ panel_session_die (GnomeClient *client,
 
 	xstuff_unsetup_desktop_area ();
 			
-	extern_shutdown ();
+	panel_shell_unregister ();
 	
 	gtk_main_quit();
+
 	return TRUE;
 }
 
@@ -904,39 +795,6 @@ panel_quit (void)
 				   GNOME_INTERACT_ANY, 0, 1);
 }
 
-#ifdef FIXME
-/* try evil hacks to rewrite panel config from old applets (gnomepager for
- * now.  This is very evil.  But that's the only way to do it, it seems */
-static gboolean
-try_evil_config_hacks (const char *goad_id, PanelWidget *panel, int pos)
-{
-	gboolean ret = FALSE;
-
-	if (strcmp (goad_id, "gnomepager_applet") == 0) {
-		static gboolean first_time = TRUE;
-		static gboolean in_path = FALSE;
-
-		if(first_time) {
-			char *tmp;
-			tmp = g_find_program_in_path ("gnomepager_applet");
-			in_path = tmp != NULL;
-			first_time = FALSE;
-			g_free(tmp);
-		}
-
-		if (!in_path) {
-			extern_load_applet ("deskguide_applet", NULL,
-					    panel, pos, TRUE, TRUE);
-
-			extern_load_applet ("tasklist_applet", NULL,
-					    panel, pos+1, TRUE, TRUE);
-			ret = TRUE;
-		}
-	}
-	return ret;
-}
-#endif /* FIXME */
-
 char *
 get_correct_prefix (char const **sep)
 {
@@ -998,7 +856,7 @@ push_correct_global_prefix (void)
 }
 
 static void
-init_user_applets (void)
+session_init_user_applets (void)
 {
 	GString *buf;
 	int count, num;	
@@ -1070,29 +928,17 @@ init_user_applets (void)
 		pos += (conditional_get_bool ("right_stick", FALSE, NULL)
 			? G_MAXINT/2 : 0);
 
-#ifdef FIXME 
-		if (strcmp (applet_name, EXTERN_ID) == 0) {
-			char *goad_id = conditional_get_string ("goad_id",
-								NULL, NULL);
-			if ( ! string_empty (goad_id) &&
-			    /* if we try an evil hack such as loading tasklist
-			     * and deskguide instead of the desguide don't
-			     * try to load this applet in the first place */
-			    ! try_evil_config_hacks (goad_id, panel, pos)) {
-				/*this is the config path to be passed to the
-				  applet when it loads*/
-				g_string_sprintf (buf, "%sApplet_%d_Extern/",
-						  PANEL_CONFIG_PATH, num);
+		if (!strcmp (applet_name, BONOBO_ID)) {
+			char *iid;
 
-				extern_load_applet (goad_id, buf->str, 
-						    panel, pos, TRUE, TRUE);
-			}
-			g_free (goad_id);
+			iid = conditional_get_string ("iid", NULL, NULL);
 
-		} else 
-#endif /* FIXME */
+			if (iid && iid [0] )
+				panel_applet_frame_load (iid, panel, pos);
 
-		if (strcmp (applet_name, LAUNCHER_ID) == 0) { 
+			g_free (iid);
+
+		} else if (!strcmp (applet_name, LAUNCHER_ID)) { 
 			gboolean hoard = FALSE;
 			Launcher *launcher;
 			char *file;
@@ -1193,7 +1039,7 @@ init_user_applets (void)
 }
 
 static void
-init_user_panels(void)
+session_init_user_panels(void)
 {
 	GString *buf;
 	int count, num;	
@@ -1222,8 +1068,6 @@ init_user_panels(void)
 					 BORDER_BOTTOM,
 					 BASEP_EXPLICIT_HIDE /* mode */,
 					 BASEP_SHOWN /* state */,
-					 BASEP_LEVEL_DEFAULT /* level */,
-					 TRUE /* avoid_on_maximize */,
 					 PANEL_SIZE_MEDIUM,
 					 TRUE /* hidebuttons_enabled */,
 					 TRUE /* hidebutton_pixmaps */,
@@ -1256,8 +1100,6 @@ init_user_panels(void)
 		int sz;
 		BasePState state;
 		BasePMode mode;
-		BasePLevel level;
-		gboolean avoid_on_maximize;
 		BorderEdge edge;
 		char *back_pixmap, *color;
 		GdkColor back_color = {0,0,0,1};
@@ -1314,7 +1156,6 @@ init_user_panels(void)
 
 		state = conditional_get_int ("state", 0, NULL);
 		mode = conditional_get_int ("mode", 0, NULL);
-		level = conditional_get_int ("level", 0, NULL);
 		screen = conditional_get_int ("screen", 0, NULL);
 		if (screen < 0)
 			screen = 0;
@@ -1327,13 +1168,9 @@ init_user_panels(void)
 			edge = conditional_get_int ("edge", BORDER_BOTTOM,
 						    NULL);
 
-			avoid_on_maximize = conditional_get_bool
-				("avoid_on_maximize", TRUE, NULL);
-
 			panel = edge_widget_new (screen,
 						 edge, 
 						 mode, state,
-						 level, avoid_on_maximize,
 						 sz,
 						 hidebuttons_enabled,
 						 hidebutton_pixmaps_enabled,
@@ -1351,16 +1188,11 @@ init_user_panels(void)
 			align = conditional_get_int ("align", ALIGNED_LEFT,
 						     NULL);
 
-			avoid_on_maximize = conditional_get_bool
-				("avoid_on_maximize", TRUE, NULL);
-
 			panel = aligned_widget_new (screen,
 						    align,
 						    edge,
 						    mode,
 						    state,
-						    level,
-						    avoid_on_maximize,
 						    sz,
 						    hidebuttons_enabled,
 						    hidebutton_pixmaps_enabled,
@@ -1384,17 +1216,12 @@ init_user_panels(void)
 
 			offset = conditional_get_int ("offset", 0, NULL);
 
-			avoid_on_maximize = conditional_get_bool
-				("avoid_on_maximize", TRUE, NULL);
-
 			panel = sliding_widget_new (screen,
 						    anchor,
 						    offset,
 						    edge,
 						    mode,
 						    state,
-						    level,
-						    avoid_on_maximize,
 						    sz,
 						    hidebuttons_enabled,
 						    hidebutton_pixmaps_enabled,
@@ -1415,14 +1242,9 @@ init_user_panels(void)
 
 			/* FIXME: there are some issues with auto hiding drawers */
 
-			avoid_on_maximize = conditional_get_bool
-				("avoid_on_maximize", FALSE, NULL);
-
 			panel = drawer_widget_new (orient,
 						   BASEP_EXPLICIT_HIDE, 
 						   state,
-						   level,
-						   avoid_on_maximize,
 						   sz,
 						   hidebuttons_enabled,
 						   hidebutton_pixmaps_enabled,
@@ -1440,27 +1262,22 @@ init_user_panels(void)
 			break;
 		}
 		case FLOATING_PANEL: {
-			PanelOrientation orient;
+			GtkOrientation orient;
 			int x, y;
 			
 			orient = conditional_get_int ("orient",
-						      PANEL_HORIZONTAL,
+						      GTK_ORIENTATION_HORIZONTAL,
 						      NULL);
 
 			x = conditional_get_int ("x", 0, NULL);
 			y = conditional_get_int ("y", 0, NULL);
 
-			avoid_on_maximize = conditional_get_bool
-				("avoid_on_maximize", FALSE, NULL);
-
 			panel = floating_widget_new (screen,
 						     x,
 						     y,
 						     orient,
 						     mode,
 						     state,
-						     level,
-						     avoid_on_maximize,
 						     sz,
 						     hidebuttons_enabled,
 						     hidebutton_pixmaps_enabled,
@@ -1572,163 +1389,192 @@ load_system_wide (void)
 	gnome_config_pop_prefix ();
 }
 
-
 void
-load_up_globals (void)
+session_read_global_config (void)
 {
-	global_config.hide_speed = 
-		panel_gconf_global_config_get_int ("panel-hide-speed");
+	GSList *l;
 
-	global_config.minimized_size = 
-		panel_gconf_global_config_get_int ("panel-minimized-size");
+	l = panel_gconf_all_global_entries ();
 
-	global_config.hide_delay = 
-		panel_gconf_global_config_get_int ("panel-hide-delay");
+	for (; l ; l = l->next) {
+		GConfEntry *entry;
+		GConfValue *value;
+		gchar      *key;
 
-	global_config.show_delay =
-		panel_gconf_global_config_get_int ("panel-show-delay");
+		entry = (GConfEntry *)l->data;
 
-	global_config.tooltips_enabled =
-		panel_gconf_global_config_get_bool ("tooltips-enabled");
+		value = gconf_entry_get_value (entry);
 
-	global_config.keep_menus_in_memory =
-		panel_gconf_global_config_get_bool ("keep-menus-in-memory");
+		key = g_path_get_basename (gconf_entry_get_key (entry));
 
-	global_config.disable_animations =
-		panel_gconf_global_config_get_bool ("disable-animations");
+		if (!strcmp (key, "panel-animation-speed"))
+			global_config.animation_speed =
+				gconf_value_get_int (value);
 
-	global_config.autoraise = 
-		panel_gconf_global_config_get_bool ("autoraise-panel");
+		else if (!strcmp (key, "panel-minimized-speed"))
+			global_config.minimized_size =
+				gconf_value_get_int (value);
 
-	global_config.layer = 
-		panel_gconf_global_config_get_int ("panel-window-layer");
-	
-	global_config.drawer_auto_close =
-		panel_gconf_global_config_get_bool ("drawer-auto-close");
+		else if (!strcmp (key, "panel-minimized-size"))
+			global_config.minimized_size =
+				gconf_value_get_int (value);
 
-	global_config.highlight_when_over =
-		panel_gconf_global_config_get_bool ("highlight-launchers-on-mouseover");
-	
-	global_config.confirm_panel_remove =
-		panel_gconf_global_config_get_bool ("confirm-panel-remove");
+		else if (!strcmp (key, "panel-hide-delay"))
+			global_config.hide_delay =
+				gconf_value_get_int (value);
 
-	global_config.keys_enabled = 
-		panel_gconf_global_config_get_bool ("enable-key-bindings");
+		else if (!strcmp (key, "panel-show-delay"))
+			global_config.show_delay =
+				gconf_value_get_int (value);
 
-	
-	global_config.menu_key = 
-		panel_gconf_global_config_get_string ("menu-key");
-	
-	convert_string_to_keysym_state(global_config.menu_key,
-				       &global_config.menu_keysym,
-				       &global_config.menu_state);
-	
-	global_config.run_key = 
-		panel_gconf_global_config_get_string ("run-key");
+		else if (!strcmp (key, "tooltips-enabled"))
+			global_config.tooltips_enabled =
+				gconf_value_get_bool (value);
 
-	convert_string_to_keysym_state(global_config.run_key,
-				       &global_config.run_keysym,
-				       &global_config.run_state);
+		else if (!strcmp (key, "keep-menus-in-memory"))
+			global_config.keep_menus_in_memory =
+				gconf_value_get_bool (value);
 
-	global_config.screenshot_key =
-		panel_gconf_global_config_get_string ("screenshot-key");
+		else if (!strcmp (key, "disable-animations"))
+			global_config.disable_animations =
+				gconf_value_get_bool (value);
 
-	convert_string_to_keysym_state (global_config.screenshot_key,
-					&global_config.screenshot_keysym,
-					&global_config.screenshot_state);
+		else if (!strcmp (key, "autoraise-panel"))
+			global_config.autoraise =
+				gconf_value_get_bool (value);
 
-	global_config.window_screenshot_key = 
-		panel_gconf_global_config_get_string ("window-screenshot-key");
+		else if (!strcmp (key, "panel-window-layer"))
+			global_config.layer =
+				gconf_value_get_int (value);
 
-	convert_string_to_keysym_state (global_config.window_screenshot_key,
-					&global_config.window_screenshot_keysym,
-					&global_config.window_screenshot_state);
-	
-	global_config.use_large_icons =
-		panel_gconf_global_config_get_bool ("use_large_icons");
+		else if (!strcmp (key, "drawer-autoclose"))
+			global_config.drawer_auto_close =
+				gconf_value_get_bool (value);
 
-	global_config.avoid_collisions =
-		panel_gconf_global_config_get_bool ("avoid-panel-overlap");
+		else if (!strcmp (key, "auto-update-menus"))
+			g_warning ("Gman: what's this '%s' ?", key);
+
+		else if (!strcmp (key, "highlight-launchers-on-mouseover"))
+			global_config.highlight_when_over =
+				gconf_value_get_bool (value);
+
+		else if (!strcmp (key, "confirm-panel-remove"))
+			global_config.confirm_panel_remove =
+				gconf_value_get_bool (value);
+
+		else if (!strcmp (key, "enable-key-bindings"))
+			global_config.keys_enabled =
+				gconf_value_get_bool (value);
+
+		else if (!strcmp (key, "menu-key")) { 
+			if (global_config.menu_key )
+				g_free (global_config.menu_key );
+
+			global_config.menu_key =
+				g_strdup (gconf_value_get_string (value));
+
+			convert_string_to_keysym_state (global_config.menu_key,
+							&global_config.menu_keysym,
+							&global_config.menu_state);
+		} else if (!strcmp (key, "run-key")) {
+			if (global_config.run_key )
+				g_free (global_config.run_key );
+
+			global_config.run_key =
+				 g_strdup (gconf_value_get_string (value));
+
+			convert_string_to_keysym_state (global_config.run_key,
+							&global_config.run_keysym,
+							&global_config.run_state);
+		} else if (!strcmp (key, "screenshot-key")) {
+			if (global_config.screenshot_key )
+				g_free (global_config.screenshot_key );
+
+			global_config.screenshot_key =
+				g_strdup (gconf_value_get_string (value));
+
+			convert_string_to_keysym_state (global_config.screenshot_key,
+							&global_config.screenshot_keysym,
+							&global_config.screenshot_state);
+
+		} else if (!strcmp (key, "window-screenshot-key")) {
+			if (global_config.window_screenshot_key )
+				g_free (global_config.window_screenshot_key );
+
+			global_config.window_screenshot_key =
+				g_strdup (gconf_value_get_string (value));
+
+			convert_string_to_keysym_state (global_config.window_screenshot_key,
+							&global_config.window_screenshot_keysym,
+							&global_config.window_screenshot_state);
+
+		} else if (!strcmp (key, "use-large-icons"))
+			global_config.use_large_icons =
+				gconf_value_get_bool (value);
+
+		else if (!strcmp (key, "avoid-panel-overlap"))
+			global_config.avoid_collisions =
+				gconf_value_get_bool (value);
+
+		else
+			g_warning ("%s not handled", key);
+
+		g_free (key);
+	}
+
+	g_slist_free (l);
 
 	/* FIXME STUFF THAT IS BORKED */
 	global_config.merge_menus = TRUE;
 	global_config.menu_check = TRUE;
 	global_config.menu_flags = get_default_menu_flags();
-/*
-	global_config.merge_menus =
-		conditional_get_bool ("merge_menus", TRUE, NULL);
-
-	global_config.menu_check =
-		conditional_get_bool ("menu_check", TRUE, NULL);
-
-	
-	global_config.menu_flags = conditional_get_int
-		("menu_flags", get_default_menu_flags (), NULL);
-	if (global_config.menu_flags < 0) {
-		global_config.menu_flags = get_default_menu_flags ();
-	}
-*/
-	gnome_config_sync ();
 
 	apply_global_config ();
-	
 }
 
 void
-write_global_config (void)
+session_write_global_config (void)
 {
-	gnome_config_push_prefix ("/panel/Config/");
-/* FIXME
-	gnome_config_set_int ("hide_speed",
-			      global_config.hide_speed);
-	gnome_config_set_int ("minimized_size",
-			      global_config.minimized_size);
-	gnome_config_set_int ("hide_delay",
-			      global_config.hide_delay);
-	gnome_config_set_int ("show_delay",
-			      global_config.show_delay);
-	gnome_config_set_bool ("tooltips_enabled",
-			       global_config.tooltips_enabled);
-	gnome_config_set_bool ("use_large_icons",
-			       global_config.use_large_icons);
-	gnome_config_set_bool ("merge_menus",
-			       global_config.merge_menus);
-	gnome_config_set_bool ("menu_check",
-			       global_config.menu_check);
-	gnome_config_set_bool ("off_panel_popups",
-			       global_config.off_panel_popups);
-	gnome_config_set_bool ("disable_animations",
-			       global_config.disable_animations);
-	gnome_config_set_bool ("autoraise",
-			       global_config.autoraise);
-	gnome_config_set_bool ("keep_bottom",
-			       global_config.keep_bottom);
-	gnome_config_set_bool ("normal_layer",
-			       global_config.normal_layer);
-	gnome_config_set_bool ("drawer_auto_close",
-			       global_config.drawer_auto_close);
-	gnome_config_set_bool ("saturate_when_over",
-			       global_config.saturate_when_over);
-	gnome_config_set_bool ("confirm_panel_remove",
-			       global_config.confirm_panel_remove);
-	gnome_config_set_int ("menu_flags", global_config.menu_flags);
-	gnome_config_set_bool ("keys_enabled", global_config.keys_enabled);
-	gnome_config_set_string ("menu_key", global_config.menu_key);
-	gnome_config_set_string ("run_key", global_config.run_key);
-	gnome_config_set_string ("screenshot_key",
-				 global_config.screenshot_key);
-	gnome_config_set_string ("window_screenshot_key",
-				 global_config.window_screenshot_key);
-	gnome_config_set_bool ("avoid_collisions",
-			       global_config.avoid_collisions);
-			     
-*/	
-	gnome_config_pop_prefix();
-	gnome_config_sync();
+	GConfChangeSet *global_config_cs;
+
+	global_config_cs = gconf_change_set_new ();
+
+	/* FIXME - I promise I will use a GConfChangeSet for this stuff */
 	
+	/* FIXME STUFF THAT IS BORKED 
+	panel_gconf_global_config_set_int ("menu-flags", global_config.menu_flags);
+	panel_gconf_global_config_set_bool ("merge-menus", global_config.merge_menus);
+	panel_gconf_global_config_set_bool ("menu-check", global_config.menu_check);
+	*/
+
+	gconf_change_set_set_int (global_config_cs, "panel-animation-speed", global_config.animation_speed);
+	gconf_change_set_set_int (global_config_cs, "panel-minimized-speed", global_config.minimized_size);
+	gconf_change_set_set_int (global_config_cs, "panel-hide-delay", global_config.hide_delay);
+	gconf_change_set_set_int (global_config_cs, "panel-show-delay", global_config.show_delay);
+	gconf_change_set_set_int (global_config_cs, "panel-window-layer", global_config.layer);
+
+	gconf_change_set_set_bool (global_config_cs, "tooltips-enabled", global_config.tooltips_enabled);
+	gconf_change_set_set_bool (global_config_cs, "use-large-icons", global_config.use_large_icons);
+	gconf_change_set_set_bool (global_config_cs, "disable-animations", global_config.disable_animations);
+	gconf_change_set_set_bool (global_config_cs, "autoraise-panel", global_config.autoraise);
+	gconf_change_set_set_bool (global_config_cs, "drawer-autoclose", global_config.drawer_auto_close);
+	gconf_change_set_set_bool (global_config_cs, "highlight-launchers-on-mouseover", global_config.highlight_when_over);
+	gconf_change_set_set_bool (global_config_cs, "confirm-panel-remove", global_config.confirm_panel_remove);
+	gconf_change_set_set_bool (global_config_cs, "keep-menus-in-memory", global_config.keep_menus_in_memory);
+	gconf_change_set_set_bool (global_config_cs, "avoid-panel-overlap", global_config.avoid_collisions);
+
+	gconf_change_set_set_string (global_config_cs, "menu-key", global_config.menu_key);
+	gconf_change_set_set_string (global_config_cs, "run-key", global_config.run_key);
+	gconf_change_set_set_string (global_config_cs, "screenshot-key", global_config.screenshot_key);
+	gconf_change_set_set_string (global_config_cs, "window-screenshot-key", global_config.window_screenshot_key);
+
+	gconf_client_commit_change_set (panel_gconf_get_client (), global_config_cs, FALSE, NULL);
+
+	gconf_change_set_unref (global_config_cs);
+			     
 }
 
-void load_session (void) {
-  init_user_panels ();
-  init_user_applets ();
+void session_load (void) {
+  session_init_user_panels ();
+  session_init_user_applets ();
 }
